webbpsf\_ext.coords
===================

.. automodule:: webbpsf_ext.coords

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      NIRCam_V2V3_limits
      ap_radec
      convert_to_sky
      dist_image
      gen_sgd_offsets
      get_NRC_v2v3_limits
      get_idl_offset
      get_sgd_offsets
      plotAxes
      radec_offset
      radec_to_coord
      radec_to_v2v3
      rtheta_to_xy
      v2v3_to_pixel
      xy_rot
      xy_to_rtheta
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      jwst_point
   
   

   
   
   



